==> apptive_grid_form-0.4.2.tar.gz: test/text_option_test.dart <==
import 'package:apptive_grid_form/widgets/apptive_grid_form_widgets.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:apptive_grid_core/apptive_grid_model.dart';

import 'common.dart';

void main() {
  group('Text', () {
    testWidgets('Default Label is Property', (tester) async {
      final property = 'Property';
      final component = StringFormComponent(
        fieldId: 'id',
        data: StringDataEntity(),
        property: property,
        options: TextComponentOptions(),
      );
      final target = TestApp(
        child: TextFormWidget(
          component: component,
        ),
      );

      await tester.pumpWidget(target);
      await tester.pumpAndSettle();

      expect(find.text(property), findsOneWidget);
    });

    testWidgets('Custom Label is shown', (tester) async {
      final property = 'Property';
      final customLabel = 'CustomLabel';
      final component = StringFormComponent(
        fieldId: 'id',
        data: StringDataEntity(),
        property: property,
        options: TextComponentOptions(
          label: customLabel,
        ),
      );
      final target = TestApp(
        child: TextFormWidget(
          component: component,
        ),
      );

      await tester.pumpWidget(target);
      await tester.pumpAndSettle();

      expect(find.text(customLabel), findsOneWidget);
    });
  });

  group('Number', () {
    testWidgets('Default Label is Property', (tester) async {
      final property = 'Property';
      final component = IntegerFormComponent(
        fieldId: 'id',
        data: IntegerDataEntity(),
        property: property,
        options: TextComponentOptions(),
      );
      final target = TestApp(
        child: IntegerFormWidget(
          component: component,
        ),
      );

      await tester.pumpWidget(target);
      await tester.pumpAndSettle();

      expect(find.text(property), findsOneWidget);
    });

    testWidgets('Custom Label is shown', (tester) async {
      final property = 'Property';
      final customLabel = 'CustomLabel';
      final component = IntegerFormComponent(
        fieldId: 'id',
        data: IntegerDataEntity(),
        property: property,
        options: TextComponentOptions(
          label: customLabel,
        ),
      );
      final target = TestApp(
        child: IntegerFormWidget(
          component: component,
        ),
      );

      await tester.pumpWidget(target);
      await tester.pumpAndSettle();

      expect(find.text(customLabel), findsOneWidget);
    });
  });
}

==> apptive_grid_form-0.11.0.tar.gz: test/text_option_test.dart <==
import 'package:apptive_grid_core/apptive_grid_model.dart';
import 'package:apptive_grid_form/widgets/apptive_grid_form_widgets.dart';
import 'package:flutter_test/flutter_test.dart';

import 'common.dart';

void main() {
  group('Text', () {
    testWidgets('Default Label is Property', (tester) async {
      const property = 'Property';
      final component = FormComponent<StringDataEntity>(
        field: GridField(id: 'String', name: 'Property', type: DataType.text),
        data: StringDataEntity(),
        property: property,
        options: const FormComponentOptions(),
      );
      final target = TestApp(
        child: TextFormWidget(
          component: component,
        ),
      );

      await tester.pumpWidget(target);
      await tester.pumpAndSettle();

      expect(find.text(property), findsOneWidget);
    });

    testWidgets('Custom Label is shown', (tester) async {
      const property = 'Property';
      const customLabel = 'CustomLabel';
      final component = FormComponent<StringDataEntity>(
        field: GridField(id: 'String', name: 'Property', type: DataType.text),
        data: StringDataEntity(),
        property: property,
        options: const FormComponentOptions(
          label: customLabel,
        ),
      );
      final target = TestApp(
        child: TextFormWidget(
          component: component,
        ),
      );

      await tester.pumpWidget(target);
      await tester.pumpAndSettle();

      expect(find.text(customLabel), findsOneWidget);
    });
  });

  group('Number', () {
    testWidgets('Default Label is Property', (tester) async {
      const property = 'Property';
      final component = FormComponent<IntegerDataEntity>(
        field: GridField(id: 'id', name: 'Property', type: DataType.integer),
        data: IntegerDataEntity(),
        property: property,
        options: const FormComponentOptions(),
      );
      final target = TestApp(
        child: IntegerFormWidget(
          component: component,
        ),
      );

      await tester.pumpWidget(target);
      await tester.pumpAndSettle();

      expect(find.text(property), findsOneWidget);
    });

    testWidgets('Custom Label is shown', (tester) async {
      const property = 'Property';
      const customLabel = 'CustomLabel';
      final component = FormComponent<IntegerDataEntity>(
        field: GridField(id: 'id', name: 'Property', type: DataType.integer),
        data: IntegerDataEntity(),
        property: property,
        options: const FormComponentOptions(
          label: customLabel,
        ),
      );
      final target = TestApp(
        child: IntegerFormWidget(
          component: component,
        ),
      );

      await tester.pumpWidget(target);
      await tester.pumpAndSettle();

      expect(find.text(customLabel), findsOneWidget);
    });
  });
}
